@@ -26,26 +26,77 @@ assert_conversion_find (const void *source,
   Babl *ret = babl_conversion_find (source, destination);
 
   if (!ret)
-    babl_fatal ("failed, aborting");
+    babl_fatal ("failed finding conversion between %s and %s aborting",
+                babl_get_name (source), babl_get_name (destination));
   return ret;
 }
 
+static int
+create_name_internal (char *buf,
+                      size_t maxlen,
+                      const Babl *source,
+                      const Babl *destination,
+                      int   is_reference)
+{
+  return snprintf (buf, maxlen, "%s %p %p",
+                   is_reference ? "ref "
+                   : "",
+                   source, destination);
+}
+
+#ifdef HAVE_TLS
+
+static __thread char buf[1024];
+
 static char *
 create_name (const Babl *source,
              const Babl *destination,
              int   is_reference)
 {
-  static char buf[1024];
+  int size = 0;
+
+  size = create_name_internal (buf, sizeof(buf), source, destination, is_reference);
+
+  if (size < 0)
+    return NULL;
 
-  /* fish names are intentionally kept short */
-  snprintf (buf, 1024, "%s %p %p",
-            is_reference ? "ref "
-            : "",
-            source, destination);
   return buf;
 }
 
 
+#else
+
+static char *
+create_name (const Babl *source,
+             const Babl *destination,
+             int   is_reference)
+{
+  int size = 0;
+  char *buf = NULL;
+
+  size = create_name_internal (buf, size, source, destination, is_reference);
+
+  if (size < 0)
+    return NULL;
+
+  size++;             /* For '\0' */
+  buf = malloc (size);
+  if (buf == NULL)
+    return NULL;
+
+  size = create_name_internal (buf, size, source, destination, is_reference);
+
+  if (size < 0)
+    {
+      free (buf);
+      return NULL;
+    }
+
+  return buf;
+}
+
+#endif
+
 Babl *
 babl_fish_reference (const Babl *source,
                      const Babl *destination)
@@ -53,12 +104,17 @@ babl_fish_reference (const Babl *source,
   Babl *babl = NULL;
   char *name = create_name (source, destination, 1);
 
+  babl_assert (name);
+
   babl = babl_db_exist_by_name (babl_fish_db (), name);
   if (babl)
     {
       /* There is an instance already registered by the required name,
        * returning the preexistent one instead.
        */
+#ifndef HAVE_TLS
+      free (name);
+#endif
       return babl;
     }
 
@@ -87,6 +143,9 @@ babl_fish_reference (const Babl *source,
    * name, inserting newly created class into database.
    */
   babl_db_insert (babl_fish_db (), babl);
+#ifndef HAVE_TLS
+  free (name);
+#endif
   return babl;
 }
 
@@ -118,6 +177,7 @@ convert_to_double (BablFormat      *source_fmt,
   src_img->pitch[0]  = source_fmt->bytes_per_pixel;
   src_img->stride[0] = 0;
 
+  {
   /* i is source position */
   for (i = 0; i < source_fmt->components; i++)
     {
@@ -142,6 +202,7 @@ convert_to_double (BablFormat      *source_fmt,
 
       src_img->data[0] += src_img->type[0]->bits / 8;
     }
+  }
   babl_free (src_img);
   babl_free (dst_img);
 }
@@ -308,7 +369,6 @@ process_to_n_component (const Babl  *babl,
   return 0;
 }
 
-
 static int
 process_same_model (const Babl  *babl,
                     const char *source,
@@ -375,17 +435,17 @@ babl_fish_reference_process (const Babl *babl,
   Babl *rgba_image;
   Babl *destination_image;
 
-
-  if (BABL (babl->fish.source)->format.model ==
-      BABL (babl->fish.destination)->format.model)
+  if ((BABL (babl->fish.source)->format.model ==
+       BABL (babl->fish.destination)->format.model) &&
+      (BABL (babl->fish.source)->format.space ==
+       BABL (babl->fish.destination)->format.space)
+      )
     return process_same_model (babl, source, destination, n);
 
   if (babl_format_is_format_n (BABL (babl->fish.destination)))
   {
     return process_to_n_component (babl, source, destination, n);
   }
-  
-
 
   source_double_buf = babl_malloc (sizeof (double) * n *
                                    BABL (babl->fish.source)->format.model->components);
@@ -396,7 +456,8 @@ babl_fish_reference_process (const Babl *babl,
   source_image = babl_image_from_linear (
     source_double_buf, BABL (BABL ((babl->fish.source))->format.model));
   rgba_image = babl_image_from_linear (
-    rgba_double_buf, babl_model_from_id (BABL_RGBA));
+    rgba_double_buf, babl_remodel_with_space (babl_model_from_id (BABL_RGBA),
+           BABL (BABL ((babl->fish.source))->format.space)) );
   destination_image = babl_image_from_linear (
     destination_double_buf, BABL (BABL ((babl->fish.destination))->format.model));
 
@@ -411,7 +472,8 @@ babl_fish_reference_process (const Babl *babl,
     Babl *conv =
       assert_conversion_find (
       BABL (babl->fish.source)->format.model,
-      babl_model_from_id (BABL_RGBA)
+      babl_remodel_with_space (babl_model_from_id (BABL_RGBA),
+           BABL (BABL ((babl->fish.source))->format.space))
       );
     if (conv->class_type == BABL_CONVERSION_PLANAR)
       {
@@ -430,10 +492,24 @@ babl_fish_reference_process (const Babl *babl,
     else babl_fatal ("oops");
   }
 
+  if (((babl->fish.source)->format.space !=
+      ((babl->fish.destination)->format.space)))
+  {
+    double matrix[9];
+    double *rgba = rgba_double_buf;
+    babl_matrix_mul_matrix (
+      (babl->fish.destination)->format.space->space.XYZtoRGB,
+      (babl->fish.source)->format.space->space.RGBtoXYZ,
+      matrix);
+
+    babl_matrix_mul_vector_buf4 (matrix, rgba, rgba, n);
+  }
+
   {
     Babl *conv =
       assert_conversion_find (
-      babl_model_from_id (BABL_RGBA),
+      babl_remodel_with_space (babl_model_from_id (BABL_RGBA),
+           BABL (BABL ((babl->fish.destination))->format.space)),
       BABL (babl->fish.destination)->format.model);
     if (conv->class_type == BABL_CONVERSION_PLANAR)
       {
@@ -468,4 +544,3 @@ babl_fish_reference_process (const Babl *babl,
   babl_free (source_double_buf);
   return n;
 }
-
